geowatch.tasks.cold.assemble\_cold\_result\_kwcoco module
=========================================================

.. automodule:: geowatch.tasks.cold.assemble_cold_result_kwcoco
   :members:
   :undoc-members:
   :show-inheritance:
